pyfatfs
=======

.. automodule:: pyfatfs

.. toctree::
   :glob:
   :maxdepth: 4

   pyfatfs.*
   CONTRIBUTING

===============
Getting started
===============

.. toctree::
   :maxdepth: 1

   pyfilesystem2_quickstart


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
